@@ -32,6 +32,8 @@ class ModelViewset(DynamicModelViewSet):
         serializer=self.get_serializer()
         if hasattr(serializer.Meta.model.objects,'for_user'):
             return serializer.Meta.model.objects.for_user(self.request.user,self.request.method)
+        if self.queryset:
+            return self.queryset
         return serializer.Meta.model.objects.all()
 
     def perform_create(self, serializer):
